import os
from launch import LaunchDescription
from launch.actions import IncludeLaunchDescription, DeclareLaunchArgument
from launch.launch_description_sources import PythonLaunchDescriptionSource
from launch.substitutions import ThisLaunchFileDir, PathJoinSubstitution
from launch_ros.actions import Node

def generate_launch_description():
    # Define the path to the Gazebo ROS package
    gazebo_ros_pkg_dir = PathJoinSubstitution(
        ['/opt', 'ros', 'jazzy', 'share', 'ros_gz_sim']
    )

    # Include the Gazebo launch file
    gazebo = IncludeLaunchDescription(
        PythonLaunchDescriptionSource([gazebo_ros_pkg_dir, '/launch/gz_sim.launch.py']),
    )

    # Define the path to your custom model
    model_path = PathJoinSubstitution(
        [os.path.expanduser('~'), 'path', 'to', 'your', 'model', 'model.sdf']
    )

    # Spawn the custom model
    spawn_entity = Node(
        package='ros_gz_sim',
        executable='ros_gz_spawn_model.launch.py',
        arguments=[
            '-entity', 'my_custom_model',
            '-file', model_path
        ],
        output='screen'
    )

    return LaunchDescription([
        DeclareLaunchArgument(
            'use_sim_time',
            default_value='true',
            description='Use simulation (Gazebo) clock if true'
        ),
        gazebo,
        spawn_entity,
    ])
